import * as i0 from '@angular/core';
import { Injectable, EventEmitter, Component, Input, Output, ViewChild, NgModule } from '@angular/core';
import interactionPlugin from '@fullcalendar/interaction';
import timeGridPlugin from '@fullcalendar/timegrid';
import dayGridPlugin from '@fullcalendar/daygrid';
import * as i1 from '@angular/common';
import { CommonModule } from '@angular/common';
import * as i2 from '@fullcalendar/angular';
import { FullCalendarModule } from '@fullcalendar/angular';
import { FormsModule, ReactiveFormsModule } from '@angular/forms';
import { BrowserModule } from '@angular/platform-browser';

class EqpCalendarService {
    constructor() { }
}
EqpCalendarService.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "15.2.10", ngImport: i0, type: EqpCalendarService, deps: [], target: i0.ɵɵFactoryTarget.Injectable });
EqpCalendarService.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "15.2.10", ngImport: i0, type: EqpCalendarService, providedIn: 'root' });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "15.2.10", ngImport: i0, type: EqpCalendarService, decorators: [{
            type: Injectable,
            args: [{
                    providedIn: 'root'
                }]
        }], ctorParameters: function () { return []; } });

class EqpCalendarComponent {
    constructor() {
        this.eventList = new Array();
        this.customStyle = { 'text-transform': 'capitalize' };
        this.initialView = "dayGridMonth";
        this.firstDay = 1;
        this.contentHeight = null;
        this.locale = "it-IT";
        this.monthButtonText = "Mese";
        this.weekButtonText = "Settimana";
        this.dayButtonText = "Giorno";
        this.todayButtonText = "Oggi";
        this.listButtonText = "Lista";
        this.headerToolbarStart = 'title';
        this.headerToolbarCenter = "dayGridMonth,timeGridWeek,timeGridDay";
        this.headerToolbarEnd = "today prev,next";
        this.allDayText = "Tutto il giorno";
        this.eventOrder = null;
        this.onViewDateChange = new EventEmitter();
        this.onDateClick = new EventEmitter();
        this.onEventClick = new EventEmitter();
        this.calendarOptions = {};
    }
    ngOnInit() {
        this.configureCalendar();
    }
    ngAfterViewInit() {
        if (this.calendarComponent)
            this.calendarApi = this.calendarComponent.getApi();
        setTimeout(() => {
            this.calendarApi.updateSize();
        }, 190);
    }
    ngOnChanges(changes) {
        if (changes['eventList'] != undefined && changes['eventList'].firstChange == false && JSON.stringify(changes['eventList'].currentValue) != JSON.stringify(changes['eventList'].previousValue)) {
            this.calendarOptions.events = this.eventList;
            this.calendarApi.refetchEvents();
        }
    }
    configureCalendar() {
        this.calendarOptions = {
            initialView: this.initialView,
            firstDay: this.firstDay,
            contentHeight: this.contentHeight,
            locale: this.locale,
            plugins: [dayGridPlugin, timeGridPlugin, interactionPlugin],
            customButtons: {
                today: {
                    text: this.todayButtonText,
                    click: (event) => {
                        this.calendarApi.today();
                        this.viewDateChange();
                    }
                },
                prev: {
                    click: (event) => {
                        this.calendarApi.prev();
                        this.viewDateChange();
                    }
                },
                next: {
                    click: (event) => {
                        this.calendarApi.next();
                        this.viewDateChange();
                    }
                },
                dayGridMonth: {
                    text: this.monthButtonText,
                    click: (event) => {
                        this.calendarApi.changeView("dayGridMonth");
                        this.viewDateChange();
                    }
                },
                timeGridWeek: {
                    text: this.weekButtonText,
                    click: (event) => {
                        this.calendarApi.changeView("timeGridWeek");
                        this.viewDateChange();
                    }
                },
                timeGridDay: {
                    text: this.dayButtonText,
                    click: (event) => {
                        this.calendarApi.changeView("timeGridDay");
                        this.viewDateChange();
                    }
                }
            },
            headerToolbar: {
                start: this.headerToolbarStart,
                center: this.headerToolbarCenter,
                end: this.headerToolbarEnd,
            },
            buttonText: {
                month: this.monthButtonText,
                week: this.weekButtonText,
                day: this.dayButtonText,
                today: this.todayButtonText,
                list: this.listButtonText
            },
            allDayText: this.allDayText,
            eventClick: (event) => { this.eventClick(event); },
            dateClick: this.dateClick.bind(this),
            eventOrder: (eventA, eventB) => { return ((eventA && eventB && this.eventOrder) ? this.eventOrder(eventA, eventB) : 0); }
        };
        this.calendarOptions.events = this.eventList;
        if (this.calendarApi)
            this.calendarApi.refetchEvents();
    }
    viewDateChange() {
        let newRange = {
            dateStart: this.calendarApi.view.currentStart,
            dateEnd: this.calendarApi.view.currentEnd,
            viewMode: this.calendarApi.view.type
        };
        this.onViewDateChange.emit(newRange);
    }
    dateClick(event) {
        this.onDateClick.emit(event.date);
    }
    eventClick(event) {
        this.onEventClick.emit(event.event);
    }
}
EqpCalendarComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "15.2.10", ngImport: i0, type: EqpCalendarComponent, deps: [], target: i0.ɵɵFactoryTarget.Component });
EqpCalendarComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "15.2.10", type: EqpCalendarComponent, selector: "eqp-calendar", inputs: { eventList: ["EventList", "eventList"], customStyle: ["CustomStyle", "customStyle"], initialView: ["InitialView", "initialView"], firstDay: ["FirstDay", "firstDay"], contentHeight: ["ContentHeight", "contentHeight"], locale: ["Locale", "locale"], monthButtonText: ["MonthButtonText", "monthButtonText"], weekButtonText: ["WeekButtonText", "weekButtonText"], dayButtonText: ["DayButtonText", "dayButtonText"], todayButtonText: ["TodayButtonText", "todayButtonText"], listButtonText: ["ListButtonText", "listButtonText"], headerToolbarStart: ["HeaderToolbarStart", "headerToolbarStart"], headerToolbarCenter: ["HeaderToolbarCenter", "headerToolbarCenter"], headerToolbarEnd: ["HeaderToolbarEnd", "headerToolbarEnd"], allDayText: ["AllDayText", "allDayText"], eventOrder: ["EventOrder", "eventOrder"] }, outputs: { onViewDateChange: "OnViewDateChange", onDateClick: "OnDateClick", onEventClick: "OnEventClick" }, viewQueries: [{ propertyName: "calendarComponent", first: true, predicate: ["calendar"], descendants: true }], usesOnChanges: true, ngImport: i0, template: "<full-calendar [options]=\"calendarOptions\" #calendar [ngStyle]=\"customStyle\"></full-calendar>", styles: [""], dependencies: [{ kind: "directive", type: i1.NgStyle, selector: "[ngStyle]", inputs: ["ngStyle"] }, { kind: "component", type: i2.FullCalendarComponent, selector: "full-calendar", inputs: ["options", "deepChangeDetection", "events", "eventSources", "resources"] }] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "15.2.10", ngImport: i0, type: EqpCalendarComponent, decorators: [{
            type: Component,
            args: [{ selector: 'eqp-calendar', template: "<full-calendar [options]=\"calendarOptions\" #calendar [ngStyle]=\"customStyle\"></full-calendar>" }]
        }], ctorParameters: function () { return []; }, propDecorators: { eventList: [{
                type: Input,
                args: ["EventList"]
            }], customStyle: [{
                type: Input,
                args: ["CustomStyle"]
            }], initialView: [{
                type: Input,
                args: ["InitialView"]
            }], firstDay: [{
                type: Input,
                args: ["FirstDay"]
            }], contentHeight: [{
                type: Input,
                args: ["ContentHeight"]
            }], locale: [{
                type: Input,
                args: ["Locale"]
            }], monthButtonText: [{
                type: Input,
                args: ["MonthButtonText"]
            }], weekButtonText: [{
                type: Input,
                args: ["WeekButtonText"]
            }], dayButtonText: [{
                type: Input,
                args: ["DayButtonText"]
            }], todayButtonText: [{
                type: Input,
                args: ["TodayButtonText"]
            }], listButtonText: [{
                type: Input,
                args: ["ListButtonText"]
            }], headerToolbarStart: [{
                type: Input,
                args: ["HeaderToolbarStart"]
            }], headerToolbarCenter: [{
                type: Input,
                args: ["HeaderToolbarCenter"]
            }], headerToolbarEnd: [{
                type: Input,
                args: ["HeaderToolbarEnd"]
            }], allDayText: [{
                type: Input,
                args: ["AllDayText"]
            }], eventOrder: [{
                type: Input,
                args: ["EventOrder"]
            }], onViewDateChange: [{
                type: Output,
                args: ["OnViewDateChange"]
            }], onDateClick: [{
                type: Output,
                args: ["OnDateClick"]
            }], onEventClick: [{
                type: Output,
                args: ["OnEventClick"]
            }], calendarComponent: [{
                type: ViewChild,
                args: ['calendar']
            }] } });

class EqpCalendarModule {
}
EqpCalendarModule.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "15.2.10", ngImport: i0, type: EqpCalendarModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule });
EqpCalendarModule.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "15.2.10", ngImport: i0, type: EqpCalendarModule, declarations: [EqpCalendarComponent], imports: [CommonModule,
        BrowserModule,
        FormsModule,
        ReactiveFormsModule,
        FullCalendarModule], exports: [EqpCalendarComponent] });
EqpCalendarModule.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "15.2.10", ngImport: i0, type: EqpCalendarModule, imports: [CommonModule,
        BrowserModule,
        FormsModule,
        ReactiveFormsModule,
        FullCalendarModule] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "15.2.10", ngImport: i0, type: EqpCalendarModule, decorators: [{
            type: NgModule,
            args: [{
                    declarations: [EqpCalendarComponent],
                    imports: [
                        CommonModule,
                        BrowserModule,
                        FormsModule,
                        ReactiveFormsModule,
                        FullCalendarModule
                    ],
                    exports: [EqpCalendarComponent]
                }]
        }] });

class ViewDateChangeEvent {
}

/*
 * Public API Surface of eqp-calendar
 */

/**
 * Generated bundle index. Do not edit.
 */

export { EqpCalendarComponent, EqpCalendarModule, EqpCalendarService, ViewDateChangeEvent };
//# sourceMappingURL=eqproject-eqp-calendar.mjs.map
